==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/network/serverbound/DodgePacket.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.network.serverbound;

import net.minecraft.class_1799;
import net.minecraft.class_2540;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_3222;
import net.minecraft.class_3419;
import net.minecraft.server.MinecraftServer;
import vazkii.botania.common.handler.BotaniaSounds;
import vazkii.botania.common.handler.EquipmentHandler;
import vazkii.botania.common.helper.ItemNBTHelper;
import vazkii.botania.common.item.BotaniaItems;
import vazkii.botania.common.item.equipment.bauble.RingOfDexterousMotionItem;
import vazkii.botania.network.BotaniaPacket;

import static vazkii.botania.common.lib.ResourceLocationHelper.prefix;

public class DodgePacket implements BotaniaPacket {
	public static final DodgePacket INSTANCE = new DodgePacket();
	public static final class_2960 ID = prefix("do");

	public static DodgePacket decode(class_2540 buf) {
		return INSTANCE;
	}

	@Override
	public void encode(class_2540 buf) {

	}

	@Override
	public class_2960 getFabricId() {
		return ID;
	}

	public void handle(MinecraftServer server, class_3222 player) {
		server.execute(() -> {
			player.field_6002.method_43128(null, player.method_23317(), player.method_23318(), player.method_23321(), BotaniaSounds.dash, class_3419.field_15248, 1F, 1F);

			class_1799 ringStack = EquipmentHandler.findOrEmpty(BotaniaItems.dodgeRing, player);
			if (ringStack.method_7960()) {
				player.field_13987.method_14367(class_2561.method_43471("botaniamisc.invalidDodge"));
				return;
			}

			player.method_7322(0.3F);
			ItemNBTHelper.setInt(ringStack, RingOfDexterousMotionItem.TAG_DODGE_COOLDOWN, RingOfDexterousMotionItem.MAX_CD);
		});
	}
}

==> Botania-1.20.1-451-FABRIC-20251117.165059-24-sources.jar: vazkii/botania/network/serverbound/DodgePacket.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.network.serverbound;

import net.minecraft.class_1799;
import net.minecraft.class_2540;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_3222;
import net.minecraft.class_3419;
import net.minecraft.server.MinecraftServer;
import vazkii.botania.common.handler.BotaniaSounds;
import vazkii.botania.common.handler.EquipmentHandler;
import vazkii.botania.common.helper.ItemNBTHelper;
import vazkii.botania.common.item.BotaniaItems;
import vazkii.botania.common.item.equipment.bauble.RingOfDexterousMotionItem;
import vazkii.botania.network.BotaniaPacket;

import static vazkii.botania.common.lib.ResourceLocationHelper.prefix;

public class DodgePacket implements BotaniaPacket {
	public static final DodgePacket INSTANCE = new DodgePacket();
	public static final class_2960 ID = prefix("do");

	public static DodgePacket decode(class_2540 buf) {
		return INSTANCE;
	}

	@Override
	public void encode(class_2540 buf) {

	}

	@Override
	public class_2960 getFabricId() {
		return ID;
	}

	public void handle(MinecraftServer server, class_3222 player) {
		server.execute(() -> {
			player.method_37908().method_43128(null, player.method_23317(), player.method_23318(), player.method_23321(), BotaniaSounds.dash, class_3419.field_15248, 1F, 1F);

			class_1799 ringStack = EquipmentHandler.findOrEmpty(BotaniaItems.dodgeRing, player);
			if (ringStack.method_7960()) {
				player.field_13987.method_14367(class_2561.method_43471("botaniamisc.invalidDodge"));
				return;
			}

			player.method_7322(0.3F);
			ItemNBTHelper.setInt(ringStack, RingOfDexterousMotionItem.TAG_DODGE_COOLDOWN, RingOfDexterousMotionItem.MAX_CD);
		});
	}
}
